OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Термін дії пароля закінчився, скористайтеся методом \"Забули пароль\", щоб перевстановити його на новий",
    "Password must not have been used recently before." : "Пароль не повинен використовуватися нещодавно.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Пароль",
    "Password is present in compromised password list. Please choose a different password." : "Пароль присутній у списку зламаних паролів. Виберіть інший пароль.",
    "Password needs to be at least %s characters long." : "Довжина пароля має бути не менше %s символів.",
    "Password needs to contain at least one numeric character." : "Пароль має містити принаймні одну цифру.",
    "Password needs to contain at least one special character." : "Пароль повинен містити хоча б один спеціальний символ.",
    "Password needs to contain at least one lower and one upper case character." : "Пароль повинен містити принаймні один символ у нижньому та один у верхньому регістрах.",
    "Password policy" : "Політика паролів",
    "Allows admins to configure a password policy" : "Дозволяє адміністраторам налаштовувати політику паролів",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Дозволити адміністратору визначати певні попередні умови для пароля, напр. дотримуватися мінімальної довжини",
    "General password policies" : "Загальні політики паролів",
    "Add policy set" : "Додати набір політик",
    "Login policies" : "Політика входу в систему",
    "Password history size" : "Розмір історії паролів",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Кількість паролів для зберігання (надійно хешованих), щоб запобігти повторному використанню користувачами раніше використаних паролів.",
    "Maximum login attempts" : "Максимальна кількість спроб входу",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Кількість спроб авторизації перед тим, як обліковий запис користувача буде вимкнено автоматично (0 - без обмежень)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Зверніть увагу, що цей параметр означає налаштування захисту для облікових записів, що перебувають під атакою. Вимкнені облікові записи потрібно буде адміністраторові повторно вручну увімкнути. Незалежно від цих налаштувань адреси IP тих, хто намагається підібрати пароль для авторизацію, буде заблоковано за допомогою захисту від підбору паролів.",
    "Number of days until user password expires" : "Кількість днів до закінчення терміну дії пароля користувача",
    "Password expiration" : "Закінчення терміну дії пароля",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Попередження: увімкнення закінчення терміну дії пароля сьогодні вважається ризиком для безпеки кількома агентствами безпеки.",
    "Remove policy" : "Політика видалення",
    "Minimum password length" : "Мінімальна довжина пароля",
    "Forbid common passwords" : "Заборонити загальні паролі",
    "Enforce upper and lower case characters" : "Має містити символи верхнього та нижнього реґістру",
    "Enforce numeric characters" : "Має містити цифри",
    "Enforce special characters" : "Має містити спеціальні символи",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Перевіряти пароль у списку зламаних паролів з сайту haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Ця перевірка створює хеш пароля та надсилає перші 5 символів цього хешу до API haveibeenpwned.com для отримання списку всіх хешів, які починаються з них. Потім він перевіряє хмару Nextcloud, чи присутній хеш пароля в наборі результатів.",
    "Account password policies" : "Політика паролів облікових записів",
    "Share password policies" : "Поділітися політиками паролів"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
